action

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2018 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package action provides types for determining the action intended to be performed by the application.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Action

type Action struct {
	// contains filtered or unexported fields
}

Action defines an intended action for the app to perform.

func Setup

func Setup(flags *flag.FlagSet) *Action

Setup sets up a lazy-valued action based on a given flag set.

NOTE: The passed flag set will have to be parsed before the action can be used. This parsing is intended to not be performed in this

func (*Action) Type

func (a *Action) Type() Type

Type returns the action type to perform.

type Type

type Type uint

Type defines the type of action intended for the app to perform.

const (
	DefineWord Type = iota
	PrintConfig
	ListSources
	PrintVersion
)

List of actions to perform.

Jump to