Documentation
¶
Overview ¶
Package action provides types for determining the action intended to be performed by the application.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Action ¶
type Action struct {
// contains filtered or unexported fields
}
Action defines an intended action for the app to perform.
Click to show internal directories.
Click to hide internal directories.